
	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit
enter search-word: 
*** Searching for word aa 
found in aa
-------document #1-----
halsen
symbolist
snarlingly
gunyang
costmary
unseamanlike
agrypnotic
esperantist
gummatous
infranuclear
articular
thrombolymphangitis
tapeworm
delichon
pasture
continualness
emancipatress
aa
ecchymose
presynaptic
gazettal
mpangwe
thiophosphate
otate
mammonize

10 pages read

	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit
enter search-prefix: 
*** Searching for prefix aa 
Prefix found in aa
Prefix found in aal
Prefix found in aalii
Prefix found in aam
Prefix found in aani
Prefix found in aardvark
Prefix found in aardwolf
Prefix found in aaron
Prefix found in aaronic
Prefix found in aaronical
Prefix found in aaronite
Prefix found in aaronitic
Prefix found in aaru
"aa" is the prefix of 13 words
13 pages read

	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit
enter search-substring: 
*** Searching for substring aa 
Substring found in aa
Substring found in aal
Substring found in aalii
Substring found in aam
Substring found in aani
Substring found in aardvark
Substring found in aardwolf
Substring found in aaron
Substring found in aaronic
Substring found in aaronical
Substring found in aaronite
Substring found in aaronitic
Substring found in aaru
Substring found in afrikaans
Substring found in ahaaina
Substring found in alcaaba
Substring found in amaas
Substring found in assbaa
Substring found in baa
Substring found in baahling
Substring found in baal
Substring found in baalath
Substring found in baalish
Substring found in baalism
Substring found in baalist
Substring found in baalite
Substring found in baalitical
Substring found in baalize
Substring found in baalshem
Substring found in baar
Substring found in balaam
Substring found in balaamite
Substring found in balaamitical
Substring found in balmacaan
Substring found in bastaard
Substring found in bataan
Substring found in baviaantje
Substring found in bazaar
Substring found in berghaan
Substring found in bilaan
Substring found in caam
Substring found in caama
Substring found in caaming
Substring found in caapeba
Substring found in caatinga
Substring found in cabaan
Substring found in canaan
Substring found in canaanite
Substring found in canaanitess
Substring found in canaanitic
Substring found in canaanitish
Substring found in chaa
Substring found in daalder
Substring found in danaan
Substring found in encraal
Substring found in enkraal
Substring found in golandaas
Substring found in graafian
Substring found in haab
Substring found in haaf
Substring found in heemraad
Substring found in isaac
Substring found in jaalin
Substring found in knorhaan
Substring found in kraal
Substring found in laager
Substring found in laang
Substring found in landsmaal
Substring found in lievaart
Substring found in maam
Substring found in maamselle
Substring found in maarten
Substring found in macaasim
Substring found in malaanonang
Substring found in molengraaffite
Substring found in mushaa
Substring found in naa
Substring found in naam
Substring found in naaman
Substring found in naassenes
Substring found in nagmaal
Substring found in paal
Substring found in paar
Substring found in paauw
Substring found in paraaminobenzoic
Substring found in praam
Substring found in raad
Substring found in raanan
Substring found in raash
Substring found in reaal
Substring found in rigsmaal
Substring found in riksmaal
Substring found in saa
Substring found in saad
Substring found in saan
Substring found in saarbrucken
Substring found in salaam
Substring found in salaamlike
Substring found in sangraal
Substring found in saraad
Substring found in schaapsteker
Substring found in schoolmaam
Substring found in schoolmaamish
Substring found in senaah
Substring found in shaatnez
Substring found in sjaak
Substring found in skokiaan
Substring found in springhaas
Substring found in staab
Substring found in staatsrat
Substring found in taa
Substring found in taal
Substring found in taalbond
Substring found in taar
Substring found in takhaar
Substring found in taysaam
Substring found in teewhaap
Substring found in tetraamylose
Substring found in transvaal
Substring found in transvaaler
Substring found in transvaalian
Substring found in tzaam
Substring found in vaagmer
Substring found in vaalite
Substring found in vaalpens
Substring found in waac
Substring found in waag
Substring found in waapa
Substring found in waar
Substring found in waasi
"aa" is in 130 words
74552 pages read

	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit

*** Exiting .........
