
	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit
enter search-word: 
*** Searching for word christos 
found in christos
-------document #1-----
wingless
zimarra
tropidoleptus
bijasal
rolfe
impending
menura
dumbfounderment
baetzner
misbeliever
puffer
steadyingly
synenergistical
noncastigation
christos
underadventurer
abolitionize
hogling
pintura
stilbestrol
melotragic
peakishly
alogical
detersively
urnism

10 pages read

	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit
enter search-prefix: 
*** Searching for prefix christos 
Prefix found in christos
"christos" is the prefix of 1 words
11 pages read

	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit
enter search-substring: 
*** Searching for substring christos 
Substring found in christos
"christos" is in 1 words
74552 pages read

	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit

*** Exiting .........
