
	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit
enter search-word: 
*** Searching for word andy 
found in andy
-------document #1-----
joggler
countergambit
improbatory
andy
spongiopilin
asci
microcosmical
tightly
myotony
corduroyed
abelicea
gaulish
sicilienne
summerite
stew
triploidic
sternly
anakrousis
pedestrianize
tarsitis
mysteriosophy
spelunker
inro
senatress
hypothenar

10 pages read

	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit
enter search-prefix: 
*** Searching for prefix andy 
Prefix found in andy
"andy" is the prefix of 1 words
10 pages read

	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit
enter search-substring: 
*** Searching for substring andy 
Substring found in andy
Substring found in bandy
Substring found in bandyball
Substring found in bandyman
Substring found in brandy
Substring found in brandyball
Substring found in brandyman
Substring found in brandywine
Substring found in candy
Substring found in candymaker
Substring found in candymaking
Substring found in candys
Substring found in candystick
Substring found in candytuft
Substring found in candyweed
Substring found in dandy
Substring found in dandydom
Substring found in dandyish
Substring found in dandyism
Substring found in dandyize
Substring found in dandyling
Substring found in handy
Substring found in handyblow
Substring found in handybook
Substring found in handygrip
Substring found in houghmagandy
Substring found in islandy
Substring found in mandyas
Substring found in organdy
Substring found in overbandy
Substring found in pandy
Substring found in quandy
Substring found in quicksandy
Substring found in randy
Substring found in sandy
Substring found in sandyish
Substring found in scrimshandy
Substring found in shandy
Substring found in shandygaff
Substring found in shandyism
Substring found in spandy
Substring found in tandy
Substring found in ultradandyism
Substring found in unhandy
Substring found in vandyke
Substring found in wandy
"andy" is in 46 words
74552 pages read

	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit

*** Exiting .........
