
	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit
enter search-word: 
*** Searching for word alskj 
found in alskj
-------document #1-----
alskjdfkas
alskj
alsk
alskjdfk 
ddddalskjbbbb
ddddalkjbbbb


10 pages read

	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit
enter search-prefix: 
*** Searching for prefix alskj 
Prefix found in alskj
Prefix found in alskjdfk
Prefix found in alskjdfkas
"alskj" is the prefix of 3 words
10 pages read

	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit
enter search-substring: 
*** Searching for substring alskj 
Substring found in alskj
Substring found in alskjdfk
Substring found in alskjdfkas
Substring found in ddddalskjbbbb
"alskj" is in 4 words
74554 pages read

	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit

*** Exiting .........
