
	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit
enter search-word: 
*** Searching for word data 
found in data
-------document #1-----
dendrobates
latibulize
blastochyle
radiographer
platyrrhinian
nucleoli
ascula
lobectomy
centriciput
preteach
plessigraph
data
insolidity
hitoshi
hockday
langsat
crinoidal
shapelessly
arrasene
chainer
gillian
lipoma
rivinian
commonwealthism
oswegan

10 pages read

	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit
enter search-prefix: 
*** Searching for prefix data 
Prefix found in data
Prefix found in datable
Prefix found in datableness
Prefix found in datably
Prefix found in dataria
Prefix found in datary
"data" is the prefix of 6 words
11 pages read

	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit
enter search-substring: 
*** Searching for substring data 
Substring found in achordata
Substring found in caudata
Substring found in cephalochordata
Substring found in chordata
Substring found in commendatary
Substring found in commodatary
Substring found in data
Substring found in datable
Substring found in datableness
Substring found in datably
Substring found in dataria
Substring found in datary
Substring found in ecaudata
Substring found in mandatary
Substring found in pedata
Substring found in predata
Substring found in prodatary
Substring found in protochordata
Substring found in pseudataxic
Substring found in subdatary
Substring found in undatable
Substring found in unliquidatable
"data" is in 22 words
74552 pages read

	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit

*** Exiting .........
