
	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit
enter search-word: 
*** Searching for word zyz 
key "zyz": not found
10 pages read

	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit
enter search-prefix: 
*** Searching for prefix zyz 
Prefix found in zyzomys
Prefix found in zyzzogeton
"zyz" is the prefix of 2 words
10 pages read

	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit
enter search-substring: 
*** Searching for substring zyz 
Substring found in zyzomys
Substring found in zyzzogeton
"zyz" is in 2 words
74552 pages read

	*** These are your commands .........
	"C" to scan the tree
	"i" to insert
	"M" to search and print instances of the key as a substring
	"p" to print a btree page
	"P" to search and print instances of the key as a prefix
	"s" to search, and print the key
	"S" to search, and print the key, posting list pairs
	"T" to print the btree in inorder format
	"x" to exit

*** Exiting .........
